# Generated by roxygen2: do not edit by hand

S3method(print,evacpath_result)
S3method(print,evacpath_tsunami_zones)
export(calc_evac_time)
export(calc_min_distance_to_safety)
export(calculate_lc_path)
export(calculate_min_dist)
export(clean_roads)
export(crop_roads_to_inner_extent)
export(find_escape_points)
export(interpolate_distance_surface)
export(make_conductance_surface)
export(make_evac_grid)
export(make_evac_polygons)
export(make_region_area)
export(make_road_aware_escape_zone)
export(make_road_mask)
export(make_road_origins)
export(make_roads_in_zone)
export(prepare_evac_inputs)
export(prepare_hazard_zone)
export(prepare_tsunami_zones)
export(read_spatial)
export(run_evacpath)
export(write_evac_outputs)
