% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/roads_conductance.R
\name{make_conductance_surface}
\alias{make_conductance_surface}
\title{Create a slope-based conductance surface}
\usage{
make_conductance_surface(
  dem,
  road_mask = NULL,
  resolution = NULL,
  method = "slope"
)
}
\arguments{
\item{dem}{Elevation raster.}

\item{road_mask}{Optional road/pathway mask.}

\item{resolution}{Optional target DEM resolution before conductance creation.}

\item{method}{Conductance method. Currently only \code{"slope"} is implemented.}
}
\value{
A \code{leastcostpath} conductance surface object.
}
\description{
Masks a DEM to an optional road/pathway mask and creates a slope conductance
surface using \code{leastcostpath}.
}
\examples{
dem <- terra::rast(nrows = 5, ncols = 5, xmin = 0, xmax = 5, ymin = 0, ymax = 5,
  vals = 1, crs = "EPSG:3857")
make_conductance_surface(dem)
}
